package cn.estsh.i3plus.ext.mes.apiservice.controller.report;

import cn.estsh.i3plus.ext.mes.api.busi.report.IMesCimSeresReportService;
import cn.estsh.i3plus.ext.mes.pojo.constant.MesCommonConstant;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.mes.bean.seres.MesCimSeresJisQueue;
import cn.estsh.i3plus.pojo.mes.bean.seres.MesCimSeresJisVinOverPoint;
import cn.estsh.i3plus.pojo.mes.bean.seres.MesCimSeresSrmRunSheetJis;
import cn.estsh.i3plus.pojo.mes.model.report.*;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Description :赛力斯报表
 * @Reference :
 * @Author : jason.niu
 * @CreateDate : 2025/03/04 09:59
 * @Modify:
 **/
@Api(tags = "赛力斯报表")
@RestController
@RequestMapping(MesCommonConstant.MES_YANFEN + "/mesCimSeresReport")
public class MesCimSeresReportController {
    @Autowired
    private IMesCimSeresReportService mesCimSeresReportService;

    @ApiOperation(value = "赛力斯JIS单接收日志", notes = "赛力斯JIS单接收日志")
    @GetMapping("/query-srm-sun-sheet-jis-log")
    public ResultBean querySrmSunSheetJisLogByPager(Integer status, Pager pager){
        try {
            ListPager<MesCimSeresSrmRunSheetJis> queryResultListPager = mesCimSeresReportService.querySrmSunSheetJisLogByPager(status, pager);
            return ResultBean.success("查询成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode()).setListPager(queryResultListPager);
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "赛力斯JIS单转正常", notes = "赛力斯JIS单转正常")
    @PostMapping("/srm-sun-sheet-jis-normal")
    public ResultBean doSrmSunSheetJisNormal(@RequestBody List<Long> ids) {
        try {
            mesCimSeresReportService.doSrmSunSheetJisNormal(ids);
            return ResultBean.success("执行成功");
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "赛力斯JIS队列接收日志", notes = "赛力斯JIS队列接收日志")
    @GetMapping("/query-jis-queue-log")
    public ResultBean queryJisQueueLogByPager(Integer checkStatus, Pager pager){
        try {
            ListPager<MesCimSeresJisQueue> queryResultListPager = mesCimSeresReportService.queryJisQueueLogByPager(checkStatus, pager);
            return ResultBean.success("查询成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode()).setListPager(queryResultListPager);
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "赛力斯JIS队列转正常", notes = "赛力斯JIS队列转正常")
    @PostMapping("/jis-queue-normal")
    public ResultBean doJisQueueNormal(@RequestBody List<Long> ids) {
        try {
            mesCimSeresReportService.doJisQueueNormal(ids);
            return ResultBean.success("执行成功");
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "赛力斯过点信息查询", notes = "赛力斯过点信息查询")
    @GetMapping("/query-jis-vin-over-point")
    public ResultBean queryJisVinOverPointByPager(MesCimSeresJisVinOverPoint request, Pager pager){
        try {
            ListPager<MesCimSeresJisVinOverPoint> queryResultListPager = mesCimSeresReportService.queryJisVinOverPointByPager(request, pager);
            return ResultBean.success("查询成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode()).setListPager(queryResultListPager);
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "赛力斯排序信息查询", notes = "赛力斯排序信息查询")
    @GetMapping("/query-jis-queue")
    public ResultBean queryJisQueueByPager(MesCimSeresJisQueueRequest request, Pager pager){
        try {
            ListPager<MesCimSeresJisQueue> queryResultListPager = mesCimSeresReportService.queryJisQueueByPager(request, pager);
            return ResultBean.success("查询成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode()).setListPager(queryResultListPager);
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "赛力斯排序信息汇总", notes = "赛力斯排序信息汇总")
    @GetMapping("/query-jis-queue-summary")
    public ResultBean queryJisQueueSummaryByPager(MesCimSeresJisQueueSummaryRequest request, Pager pager){
        try {
            ListPager<MesCimSeresJisQueueSummaryResponse> queryResultListPager = mesCimSeresReportService.queryJisQueueSummaryByPager(request, pager);
            return ResultBean.success("查询成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode()).setListPager(queryResultListPager);
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }

    @ApiOperation(value = "数据二维报表", notes = "数据二维报表")
    @GetMapping("/query-data-two-dimensional")
    public ResultBean queryTwoDimensionalByPager(DataTwoDimensionalModel request, Pager pager){
        try {
            ListPager<DataTwoDimensionalModel> queryResultListPager = mesCimSeresReportService.queryTwoDimensionalByPager(request, pager);
            return ResultBean.success("查询成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode()).setListPager(queryResultListPager);
        } catch (ImppBusiException e) {
            return ResultBean.fail(e);
        } catch (Exception e) {
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }
}
